inspection_camera library

Classes

CameraController
Controls a device camera.
CameraDescription
Properties of a camera device.
CameraImage
A single complete image buffer from the platform camera.
CameraInternalImage
CameraInternalVideo
CameraModule
CameraModuleCallbacks
CameraPreview
A widget showing a live camera preview.
CameraValue
The state of a CameraController.
CaptureWidgetBuilders
ImageCaptureCallbacks
ImageCaptureConfig
ImageFormat
Describes how pixels are represented in an image.
ImageProcessor
InspectionCamera
InspectionImage
InspectionMedia<T extends MediaCaptureConfig>
InspectionVideo
MediaCaptureConfig
Optional<T>
A value that might be absent.
Plane
A single color plane of image data.
VideoCaptureCallbacks
VideoCaptureConfig
VideoPreviewWidget
Stateful widget to fetch and then display video content.
VideoPreviewWidgetState
XFile
A CrossFile is a cross-platform, simplified File abstraction.

Enums

CameraLensDirection
The direction the camera is facing.
CameraLensType
Represents various built-in camera lens types available on a device.
CameraOrientation
CompressFormat
ExposureMode
The possible exposure modes that can be set for a camera.
FlashMode
The possible flash modes that can be set for a camera
FocusMode
The possible focus modes that can be set for a camera.
ImageFormatGroup
Group of image formats that are comparable across Android and iOS platforms.
ResolutionPreset
Affect the quality of video recording and image capture:

Functions

availableCameras() Future<List<CameraDescription>>
Completes with a list of available cameras.

Typedefs

CaptureFailureHandler = bool Function(int failureAtIndex, MediaCaptureConfig captureConfig, ({Object? exception, StackTrace? stackTrace}) exceptionInfo)
CaptureFlowHandler = Future<bool> Function(int currentIndex, MediaCaptureConfig captureConfig)
MediaPreviewBuilder = Widget Function(BuildContext context, Widget mediaWidget)
onLatestImageAvailable = void Function(CameraImage image)
Signature for a callback receiving the a camera image.
ScreenOrientationBuilder = Widget Function(BuildContext context, Orientation orientation)
VideoCaptureIconBuilder = Widget Function(BuildContext context, {required bool isVideoCapturing})
VideoOverlayBuilder = Widget Function(BuildContext context, Timer? timer)

Exceptions / Errors

CameraException
This is thrown when the plugin reports an error.
FfmpegException