CameraModule class

Constructors

CameraModule({required NavigationHandler navigationHandler, CachedLocationHandler? cachedLocationHandler, ImageCaptureConfig? defaultCaptureConfig})

Properties

cachedLocationHandler CachedLocationHandler
final
defaultCaptureConfig ImageCaptureConfig
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture({MediaCaptureConfig captureConfig(MediaCaptureConfig defaultConfig)?, List<CameraDescription>? cameras}) Future<InspectionMedia<MediaCaptureConfig>?>
captureMultiple({required List<MediaCaptureConfig> captureConfigs(ImageCaptureConfig defaultConfig), required void onPictureTaken(int index, MediaCaptureConfig captureConfig, InspectionMedia<MediaCaptureConfig> data), CaptureFailureHandler? onCaptureFailure, CaptureFlowHandler? captureFlowHandler}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited